@@ -17,7 +17,7 @@ versatile DVD ripper and video transcoder (cli and GUI)
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/014/720/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
