@@ -17,7 +17,7 @@ basic install of MATE desktop
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/010/990/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
